@@ -14,40 +14,40 @@
  * limitations under the License.
  *
 */
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/camera_info.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/camera_info.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Event.hh>
-#include <gz/common/Image.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/common/StringUtils.hh>
-#include <gz/math/Angle.hh>
-#include <gz/math/Helpers.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Event.hh>
+#include <ignition/common/Image.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/StringUtils.hh>
+#include <ignition/math/Angle.hh>
+#include <ignition/math/Helpers.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sensors/CameraSensor.hh"
-#include "gz/sensors/ImageGaussianNoiseModel.hh"
-#include "gz/sensors/ImageNoise.hh"
-#include "gz/sensors/Manager.hh"
-#include "gz/sensors/RenderingEvents.hh"
-#include "gz/sensors/SensorFactory.hh"
-#include "gz/sensors/SensorTypes.hh"
+#include "ignition/sensors/CameraSensor.hh"
+#include "ignition/sensors/ImageGaussianNoiseModel.hh"
+#include "ignition/sensors/ImageNoise.hh"
+#include "ignition/sensors/Manager.hh"
+#include "ignition/sensors/RenderingEvents.hh"
+#include "ignition/sensors/SensorFactory.hh"
+#include "ignition/sensors/SensorTypes.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace sensors;
 
 /// \brief Private data for CameraSensor
-class gz::sensors::CameraSensorPrivate
+class ignition::sensors::CameraSensorPrivate
 {
   /// \brief Save an image
   /// \param[in] _data the image data to be saved
@@ -59,7 +59,7 @@ class gz::sensors::CameraSensorPrivate
   /// of the path was not possible.
   /// \sa ImageSaver
   public: bool SaveImage(const unsigned char *_data, unsigned int _width,
-    unsigned int _height, common::Image::PixelFormatType _format);
+    unsigned int _height, ignition::common::Image::PixelFormatType _format);
 
   /// \brief node to create publisher
   public: transport::Node node;
@@ -74,21 +74,21 @@ class gz::sensors::CameraSensorPrivate
   public: bool initialized = false;
 
   /// \brief Rendering camera
-  public: rendering::CameraPtr camera;
+  public: ignition::rendering::CameraPtr camera;
 
   /// \brief Pointer to an image to be published
-  public: rendering::Image image;
+  public: ignition::rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
 
   /// \brief Event that is used to trigger callbacks when a new image
   /// is generated
-  public: common::EventT<
-          void(const msgs::Image &)> imageEvent;
+  public: ignition::common::EventT<
+          void(const ignition::msgs::Image &)> imageEvent;
 
   /// \brief Connection to the Manager's scene change event.
-  public: common::ConnectionPtr sceneChangeConnection;
+  public: ignition::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -141,6 +141,7 @@ bool CameraSensor::CreateCamera()
   this->dataPtr->camera->SetImageHeight(height);
   this->dataPtr->camera->SetNearClipPlane(cameraSdf->NearClip());
   this->dataPtr->camera->SetFarClipPlane(cameraSdf->FarClip());
+  this->dataPtr->camera->SetVisibilityMask(cameraSdf->VisibilityMask());
   this->AddSensor(this->dataPtr->camera);
 
   const std::map<SensorNoiseType, sdf::Noise> noises = {
@@ -188,7 +189,7 @@ bool CameraSensor::CreateCamera()
   switch (pixelFormat)
   {
     case sdf::PixelFormatType::RGB_INT8:
-      this->dataPtr->camera->SetImageFormat(rendering::PF_R8G8B8);
+      this->dataPtr->camera->SetImageFormat(ignition::rendering::PF_R8G8B8);
       break;
     default:
       ignerr << "Unsupported pixel format ["
@@ -257,13 +258,8 @@ bool CameraSensor::Load(const sdf::Sensor &_sdf)
   if (this->Topic().empty())
     this->SetTopic("/camera");
 
-  if (!_sdf.CameraSensor()->CameraInfoTopic().empty())
-  {
-    this->dataPtr->infoTopic = _sdf.CameraSensor()->CameraInfoTopic();
-  }
-
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<msgs::Image>(
+      this->dataPtr->node.Advertise<ignition::msgs::Image>(
           this->Topic());
   if (!this->dataPtr->pub)
   {
@@ -298,14 +294,14 @@ bool CameraSensor::Load(sdf::ElementPtr _sdf)
 }
 
 /////////////////////////////////////////////////
-common::ConnectionPtr CameraSensor::ConnectImageCallback(
-    std::function<void(const msgs::Image &)> _callback)
+ignition::common::ConnectionPtr CameraSensor::ConnectImageCallback(
+    std::function<void(const ignition::msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void CameraSensor::SetScene(rendering::ScenePtr _scene)
+void CameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -320,7 +316,14 @@ void CameraSensor::SetScene(rendering::ScenePtr _scene)
 }
 
 //////////////////////////////////////////////////
-bool CameraSensor::Update(const common::Time &_now)
+bool CameraSensor::Update(
+  const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool CameraSensor::Update(const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("CameraSensor::Update");
   if (!this->dataPtr->initialized)
@@ -375,15 +378,15 @@ bool CameraSensor::Update(const common::Time &_now)
   unsigned int height = this->dataPtr->camera->ImageHeight();
   unsigned char *data = this->dataPtr->image.Data<unsigned char>();
 
-  common::Image::PixelFormatType
+  ignition::common::Image::PixelFormatType
       format{common::Image::UNKNOWN_PIXEL_FORMAT};
   msgs::PixelFormatType msgsPixelFormat =
     msgs::PixelFormatType::UNKNOWN_PIXEL_FORMAT;
 
   switch (this->dataPtr->camera->ImageFormat())
   {
-    case rendering::PF_R8G8B8:
-      format = common::Image::RGB_INT8;
+    case ignition::rendering::PF_R8G8B8:
+      format = ignition::common::Image::RGB_INT8;
       msgsPixelFormat = msgs::PixelFormatType::RGB_INT8;
       break;
     default:
@@ -393,7 +396,7 @@ bool CameraSensor::Update(const common::Time &_now)
   }
 
   // create message
-  msgs::Image msg;
+  ignition::msgs::Image msg;
   {
     IGN_PROFILE("CameraSensor::Update Message");
     msg.set_width(width);
@@ -401,11 +404,10 @@ bool CameraSensor::Update(const common::Time &_now)
     msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
                  this->dataPtr->camera->ImageFormat()));
     msg.set_pixel_format_type(msgsPixelFormat);
-    msg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-    msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
+    *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
     auto frame = msg.mutable_header()->add_data();
     frame->set_key("frame_id");
-    frame->add_value(this->FrameId());
+    frame->add_value(this->Name());
     msg.set_data(data, this->dataPtr->camera->ImageMemorySize());
   }
 
@@ -444,12 +446,12 @@ bool CameraSensor::Update(const common::Time &_now)
 //////////////////////////////////////////////////
 bool CameraSensorPrivate::SaveImage(const unsigned char *_data,
     unsigned int _width, unsigned int _height,
-    common::Image::PixelFormatType _format)
+    ignition::common::Image::PixelFormatType _format)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!common::isDirectory(this->saveImagePath))
+  if (!ignition::common::isDirectory(this->saveImagePath))
   {
-    if (!common::createDirectories(this->saveImagePath))
+    if (!ignition::common::createDirectories(this->saveImagePath))
       return false;
   }
 
@@ -457,11 +459,11 @@ bool CameraSensorPrivate::SaveImage(const unsigned char *_data,
                          std::to_string(this->saveImageCounter) + ".png";
   ++this->saveImageCounter;
 
-  common::Image localImage;
+  ignition::common::Image localImage;
   localImage.SetFromData(_data, _width, _height, _format);
 
   localImage.SavePNG(
-      common::joinPaths(this->saveImagePath, filename));
+      ignition::common::joinPaths(this->saveImagePath, filename));
   return true;
 }
 
@@ -496,17 +498,17 @@ std::string CameraSensor::InfoTopic() const
 //////////////////////////////////////////////////
 bool CameraSensor::AdvertiseInfo()
 {
-  if (this->dataPtr->infoTopic.empty())
+  // TODO(anyone) Make info topic configurable from SDF
+  // Info topic must be at same level as image topic
+  auto parts = common::Split(this->Topic(), '/');
+  parts.pop_back();
+
+  for (const auto &part : parts)
   {
-    auto parts = common::Split(this->Topic(), '/');
-    parts.pop_back();
-    for (const auto &part : parts)
-    {
-      if (!part.empty())
-        this->dataPtr->infoTopic += "/" + part;
-    }
-    this->dataPtr->infoTopic += "/camera_info";
+    if (!part.empty())
+      this->dataPtr->infoTopic += "/" + part;
   }
+  this->dataPtr->infoTopic += "/camera_info";
 
   return this->AdvertiseInfo(this->dataPtr->infoTopic);
 }
@@ -517,7 +519,7 @@ bool CameraSensor::AdvertiseInfo(const std::string &_topic)
   this->dataPtr->infoTopic = _topic;
 
   this->dataPtr->infoPub =
-      this->dataPtr->node.Advertise<msgs::CameraInfo>(
+      this->dataPtr->node.Advertise<ignition::msgs::CameraInfo>(
       this->dataPtr->infoTopic);
   if (!this->dataPtr->infoPub)
   {
@@ -534,14 +536,21 @@ bool CameraSensor::AdvertiseInfo(const std::string &_topic)
 }
 
 //////////////////////////////////////////////////
-void CameraSensor::PublishInfo(const common::Time &_now)
+void CameraSensor::PublishInfo(
+  const std::chrono::steady_clock::duration &_now)
 {
-  this->dataPtr->infoMsg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-  this->dataPtr->infoMsg.mutable_header()->mutable_stamp()->set_nsec(
-      _now.nsec);
+  *this->dataPtr->infoMsg.mutable_header()->mutable_stamp() =
+    msgs::Convert(_now);
   this->dataPtr->infoPub.Publish(this->dataPtr->infoMsg);
 }
 
+//////////////////////////////////////////////////
+void CameraSensor::PublishInfo(
+  const ignition::common::Time &_now)
+{
+  this->PublishInfo(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
 //////////////////////////////////////////////////
 void CameraSensor::PopulateInfo(const sdf::Camera *_cameraSdf)
 {
@@ -573,18 +582,19 @@ void CameraSensor::PopulateInfo(const sdf::Camera *_cameraSdf)
   intrinsics->add_k(0.0);
   intrinsics->add_k(1.0);
 
+  // TODO(anyone) Get tx and ty from SDF
   msgs::CameraInfo::Projection *proj =
     this->dataPtr->infoMsg.mutable_projection();
 
-  proj->add_p(_cameraSdf->LensProjectionFx());
+  proj->add_p(_cameraSdf->LensIntrinsicsFx());
   proj->add_p(0.0);
-  proj->add_p(_cameraSdf->LensProjectionCx());
-  proj->add_p(_cameraSdf->LensProjectionTx());
+  proj->add_p(_cameraSdf->LensIntrinsicsCx());
+  proj->add_p(-_cameraSdf->LensIntrinsicsFx() * this->dataPtr->baseline);
 
   proj->add_p(0.0);
-  proj->add_p(_cameraSdf->LensProjectionFy());
-  proj->add_p(_cameraSdf->LensProjectionCy());
-  proj->add_p(_cameraSdf->LensProjectionTy());
+  proj->add_p(_cameraSdf->LensIntrinsicsFy());
+  proj->add_p(_cameraSdf->LensIntrinsicsCy());
+  proj->add_p(0.0);
 
   proj->add_p(0.0);
   proj->add_p(0.0);
@@ -610,7 +620,7 @@ void CameraSensor::PopulateInfo(const sdf::Camera *_cameraSdf)
   // can populate it with arbitrary frames.
   auto infoFrame = this->dataPtr->infoMsg.mutable_header()->add_data();
   infoFrame->set_key("frame_id");
-  infoFrame->add_value(this->FrameId());
+  infoFrame->add_value(this->Name());
 
   this->dataPtr->infoMsg.set_width(width);
   this->dataPtr->infoMsg.set_height(height);
