@@ -17,9 +17,9 @@
 #include <gtest/gtest.h>
 #include <sdf/sdf.hh>
 
-#include <gz/sensors/Export.hh>
-#include <gz/sensors/CameraSensor.hh>
-#include <gz/sensors/Manager.hh>
+#include <ignition/sensors/Export.hh>
+#include <ignition/sensors/CameraSensor.hh>
+#include <ignition/sensors/Manager.hh>
 
 sdf::ElementPtr cameraToBadSdf()
 {
@@ -48,8 +48,7 @@ sdf::ElementPtr cameraToBadSdf()
 
 sdf::ElementPtr CameraToSdf(const std::string &_type,
     const std::string &_name, double _updateRate,
-    const std::string &_topic, const std::string &_cameraInfoTopic,
-    bool _alwaysOn, bool _visualize)
+    const std::string &_topic, bool _alwaysOn, bool _visualize)
 {
   std::ostringstream stream;
   stream
@@ -63,8 +62,6 @@ sdf::ElementPtr CameraToSdf(const std::string &_type,
     << "      <always_on>"<< _alwaysOn <<"</always_on>"
     << "      <visualize>" << _visualize << "</visualize>"
     << "      <camera>"
-    << "        <camera_info_topic>" << _cameraInfoTopic
-                                     << "</camera_info_topic>"
     << "        <horizontal_fov>.75</horizontal_fov>"
     << "        <image>"
     << "          <width>640</width>"
@@ -110,14 +107,6 @@ sdf::ElementPtr CameraToSdf(const std::string &_type,
     << "            <cy>124</cy>"
     << "            <s>1.2</s>"
     << "          </intrinsics>"
-    << "          <projection>"
-    << "            <p_fx>282</p_fx>"
-    << "            <p_fy>283</p_fy>"
-    << "            <p_cx>163</p_cx>"
-    << "            <p_cy>125</p_cy>"
-    << "            <tx>1</tx>"
-    << "            <ty>2</ty>"
-    << "          </projection>"
     << "        </lens>"
     << "      </camera>"
     << "    </sensor>"
@@ -140,32 +129,32 @@ class Camera_TEST : public ::testing::Test
   // Documentation inherited
   protected: void SetUp() override
   {
-    gz::common::Console::SetVerbosity(4);
+    ignition::common::Console::SetVerbosity(4);
   }
 };
 
 //////////////////////////////////////////////////
 TEST(Camera_TEST, CreateCamera)
 {
-  gz::sensors::Manager mgr;
+  ignition::sensors::Manager mgr;
 
-  sdf::ElementPtr camSdf = CameraToSdf("camera", "my_camera", 60.0,
-    "/cam", "my_camera/camera_info", true, true);
+  sdf::ElementPtr camSdf = CameraToSdf("camera", "my_camera", 60.0, "/cam",
+      true, true);
 
   // Create a CameraSensor
-  gz::sensors::CameraSensor *cam =
-    mgr.CreateSensor<gz::sensors::CameraSensor>(camSdf);
+  ignition::sensors::CameraSensor *cam =
+    mgr.CreateSensor<ignition::sensors::CameraSensor>(camSdf);
 
   // Make sure the above dynamic cast worked.
   ASSERT_NE(nullptr, cam);
 
   // Check topics
   EXPECT_EQ("/cam", cam->Topic());
-  EXPECT_EQ("my_camera/camera_info", cam->InfoTopic());
+  EXPECT_EQ("/camera_info", cam->InfoTopic());
 
   // however camera is not loaded because a rendering scene is missing so
   // updates will not be successful and image size will be 0
-  EXPECT_FALSE(cam->Update(gz::common::Time()));
+  EXPECT_FALSE(cam->Update(std::chrono::steady_clock::duration::zero()));
   EXPECT_EQ(0u, cam->ImageWidth());
   EXPECT_EQ(0u, cam->ImageHeight());
 
@@ -173,8 +162,8 @@ TEST(Camera_TEST, CreateCamera)
   sdf::ElementPtr camBadSdf = cameraToBadSdf();
 
   // Create a CameraSensor
-  gz::sensors::CameraSensor *badCam =
-    mgr.CreateSensor<gz::sensors::CameraSensor>(camBadSdf);
+  ignition::sensors::CameraSensor *badCam =
+    mgr.CreateSensor<ignition::sensors::CameraSensor>(camBadSdf);
   EXPECT_TRUE(badCam == nullptr);
 }
 
@@ -188,55 +177,52 @@ TEST(Camera_TEST, Topic)
   const bool visualize = 1;
 
   // Factory
-  gz::sensors::Manager mgr;
+  ignition::sensors::Manager mgr;
 
   // Default topic
   {
     const std::string topic;
-    const std::string cameraInfoTopic;
-    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, cameraInfoTopic,
-      alwaysOn, visualize);
+    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, alwaysOn,
+        visualize);
 
     auto sensorId = mgr.CreateSensor(cameraSdf);
-    EXPECT_NE(gz::sensors::NO_SENSOR, sensorId);
+    EXPECT_NE(ignition::sensors::NO_SENSOR, sensorId);
 
     auto sensor = mgr.Sensor(sensorId);
     EXPECT_NE(nullptr, sensor);
 
-    auto camera = dynamic_cast<gz::sensors::CameraSensor *>(sensor);
+    auto camera = dynamic_cast<ignition::sensors::CameraSensor *>(sensor);
     ASSERT_NE(nullptr, camera);
 
     EXPECT_EQ("/camera", camera->Topic());
-    EXPECT_EQ("/camera_info", camera->InfoTopic());
   }
 
   // Convert to valid topic
   {
     const std::string topic = "/topic with spaces/@~characters//";
-    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, "", alwaysOn,
+    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, alwaysOn,
         visualize);
 
     auto sensorId = mgr.CreateSensor(cameraSdf);
-    EXPECT_NE(gz::sensors::NO_SENSOR, sensorId);
+    EXPECT_NE(ignition::sensors::NO_SENSOR, sensorId);
 
     auto sensor = mgr.Sensor(sensorId);
     EXPECT_NE(nullptr, sensor);
 
-    auto camera = dynamic_cast<gz::sensors::CameraSensor *>(sensor);
+    auto camera = dynamic_cast<ignition::sensors::CameraSensor *>(sensor);
     ASSERT_NE(nullptr, camera);
 
     EXPECT_EQ("/topic_with_spaces/characters", camera->Topic());
-    EXPECT_EQ("/topic_with_spaces/camera_info", camera->InfoTopic());
   }
 
   // Invalid topic
   {
     const std::string topic = "@@@";
-    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, "", alwaysOn,
+    auto cameraSdf = CameraToSdf(type, name, updateRate, topic, alwaysOn,
         visualize);
 
     auto sensorId = mgr.CreateSensor(cameraSdf);
-    EXPECT_EQ(gz::sensors::NO_SENSOR, sensorId);
+    EXPECT_EQ(ignition::sensors::NO_SENSOR, sensorId);
   }
 }
 
