@@ -14,34 +14,34 @@
  * limitations under the License.
  *
 */
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/pointcloud_packed.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/pointcloud_packed.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Image.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/common/SystemPaths.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Image.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/SystemPaths.hh>
 
-#include <gz/math/Angle.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/math/Angle.hh>
+#include <ignition/math/Helpers.hh>
 
-#include <gz/transport/Node.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sensors/DepthCameraSensor.hh"
-#include "gz/sensors/Manager.hh"
-#include "gz/sensors/SensorFactory.hh"
-#include "gz/sensors/ImageGaussianNoiseModel.hh"
-#include "gz/sensors/ImageNoise.hh"
-#include "gz/sensors/RenderingEvents.hh"
+#include "ignition/sensors/DepthCameraSensor.hh"
+#include "ignition/sensors/Manager.hh"
+#include "ignition/sensors/SensorFactory.hh"
+#include "ignition/sensors/ImageGaussianNoiseModel.hh"
+#include "ignition/sensors/ImageNoise.hh"
+#include "ignition/sensors/RenderingEvents.hh"
 
 #include "PointCloudUtil.hh"
 
@@ -52,7 +52,7 @@
 #endif
 
 /// \brief Private data for DepthCameraSensor
-class gz::sensors::DepthCameraSensorPrivate
+class ignition::sensors::DepthCameraSensorPrivate
 {
   /// \brief Save an image
   /// \param[in] _data the image data to be saved
@@ -64,7 +64,7 @@ class gz::sensors::DepthCameraSensorPrivate
   /// of the path was not possible.
   /// \sa ImageSaver
   public: bool SaveImage(const float *_data, unsigned int _width,
-    unsigned int _height, gz::common::Image::PixelFormatType _format);
+    unsigned int _height, ignition::common::Image::PixelFormatType _format);
 
   /// \brief Helper function to convert depth data to depth image
   /// \param[in] _data depth data
@@ -84,7 +84,7 @@ class gz::sensors::DepthCameraSensorPrivate
   public: bool initialized = false;
 
     /// \brief Rendering camera
-  public: gz::rendering::DepthCameraPtr depthCamera;
+  public: ignition::rendering::DepthCameraPtr depthCamera;
 
   /// \brief Depth data buffer.
   public: float *depthBuffer = nullptr;
@@ -99,24 +99,24 @@ class gz::sensors::DepthCameraSensorPrivate
   public: float near = 0.0;
 
   /// \brief Pointer to an image to be published
-  public: gz::rendering::Image image;
+  public: ignition::rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
 
   /// \brief Event that is used to trigger callbacks when a new image
   /// is generated
-  public: gz::common::EventT<
-          void(const gz::msgs::Image &)> imageEvent;
+  public: ignition::common::EventT<
+          void(const ignition::msgs::Image &)> imageEvent;
 
   /// \brief Connection from depth camera with new depth data
-  public: gz::common::ConnectionPtr depthConnection;
+  public: ignition::common::ConnectionPtr depthConnection;
 
   /// \brief Connection from depth camera with new point cloud data
-  public: gz::common::ConnectionPtr pointCloudConnection;
+  public: ignition::common::ConnectionPtr pointCloudConnection;
 
   /// \brief Connection to the Manager's scene change event.
-  public: gz::common::ConnectionPtr sceneChangeConnection;
+  public: ignition::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -147,7 +147,7 @@ class gz::sensors::DepthCameraSensorPrivate
   public: transport::Node::Publisher pointPub;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace sensors;
 
 //////////////////////////////////////////////////
@@ -178,19 +178,19 @@ bool DepthCameraSensorPrivate::ConvertDepthToImage(
 //////////////////////////////////////////////////
 bool DepthCameraSensorPrivate::SaveImage(const float *_data,
     unsigned int _width, unsigned int _height,
-    common::Image::PixelFormatType /*_format*/)
+    ignition::common::Image::PixelFormatType /*_format*/)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!common::isDirectory(this->saveImagePath))
+  if (!ignition::common::isDirectory(this->saveImagePath))
   {
-    if (!common::createDirectories(this->saveImagePath))
+    if (!ignition::common::createDirectories(this->saveImagePath))
       return false;
   }
 
   if (_width == 0 || _height == 0)
     return false;
 
-  common::Image localImage;
+  ignition::common::Image localImage;
 
   unsigned int depthSamples = _width * _height;
   unsigned int depthBufferSize = depthSamples * 3;
@@ -206,7 +206,7 @@ bool DepthCameraSensorPrivate::SaveImage(const float *_data,
   localImage.SetFromData(imgDepthBuffer, _width, _height,
       common::Image::RGB_INT8);
   localImage.SavePNG(
-      common::joinPaths(this->saveImagePath, filename));
+      ignition::common::joinPaths(this->saveImagePath, filename));
 
   delete[] imgDepthBuffer;
   return true;
@@ -275,7 +275,7 @@ bool DepthCameraSensor::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/camera/depth");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<msgs::Image>(
+      this->dataPtr->node.Advertise<ignition::msgs::Image>(
           this->Topic());
   if (!this->dataPtr->pub)
   {
@@ -292,7 +292,7 @@ bool DepthCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the point cloud publisher
   this->dataPtr->pointPub =
-      this->dataPtr->node.Advertise<msgs::PointCloudPacked>(
+      this->dataPtr->node.Advertise<ignition::msgs::PointCloudPacked>(
           this->Topic() + "/points");
   if (!this->dataPtr->pointPub)
   {
@@ -352,6 +352,8 @@ bool DepthCameraSensor::CreateCamera()
   this->dataPtr->depthCamera->SetImageHeight(height);
   this->dataPtr->depthCamera->SetNearClipPlane(near);
   this->dataPtr->depthCamera->SetFarClipPlane(far);
+  this->dataPtr->depthCamera->SetVisibilityMask(
+      cameraSdf->VisibilityMask());
 
   this->AddSensor(this->dataPtr->depthCamera);
 
@@ -445,8 +447,8 @@ void DepthCameraSensor::OnNewDepthFrame(const float *_scan,
   unsigned int depthSamples = _width * _height;
   unsigned int depthBufferSize = depthSamples * sizeof(float);
 
-  common::Image::PixelFormatType format =
-    common::Image::ConvertPixelFormat(_format);
+  ignition::common::Image::PixelFormatType format =
+    ignition::common::Image::ConvertPixelFormat(_format);
 
   if (!this->dataPtr->depthBuffer)
     this->dataPtr->depthBuffer = new float[depthSamples];
@@ -480,20 +482,20 @@ void DepthCameraSensor::OnNewRgbPointCloud(const float *_scan,
 }
 
 /////////////////////////////////////////////////
-rendering::DepthCameraPtr DepthCameraSensor::DepthCamera()
+ignition::rendering::DepthCameraPtr DepthCameraSensor::DepthCamera()
 {
   return this->dataPtr->depthCamera;
 }
 
 /////////////////////////////////////////////////
-common::ConnectionPtr DepthCameraSensor::ConnectImageCallback(
-    std::function<void(const msgs::Image &)> _callback)
+ignition::common::ConnectionPtr DepthCameraSensor::ConnectImageCallback(
+    std::function<void(const ignition::msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void DepthCameraSensor::SetScene(rendering::ScenePtr _scene)
+void DepthCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -509,7 +511,14 @@ void DepthCameraSensor::SetScene(rendering::ScenePtr _scene)
 }
 
 //////////////////////////////////////////////////
-bool DepthCameraSensor::Update(const common::Time &_now)
+bool DepthCameraSensor::Update(const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool DepthCameraSensor::Update(
+  const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("DepthCameraSensor::Update");
   if (!this->dataPtr->initialized)
@@ -533,17 +542,16 @@ bool DepthCameraSensor::Update(const common::Time &_now)
   auto msgsFormat = msgs::PixelFormatType::R_FLOAT32;
 
   // create message
-  msgs::Image msg;
+  ignition::msgs::Image msg;
   msg.set_width(width);
   msg.set_height(height);
   msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
                rendering::PF_FLOAT32_R));
   msg.set_pixel_format_type(msgsFormat);
-  msg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-  msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
+  *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
   auto frame = msg.mutable_header()->add_data();
   frame->set_key("frame_id");
-  frame->add_value(this->FrameId());
+  frame->add_value(this->Name());
 
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   msg.set_data(this->dataPtr->depthBuffer,
@@ -571,10 +579,8 @@ bool DepthCameraSensor::Update(const common::Time &_now)
       this->dataPtr->pointCloudBuffer)
   {
     // Set the time stamp
-    this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_sec(
-        _now.sec);
-    this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_nsec(
-        _now.nsec);
+    *this->dataPtr->pointMsg.mutable_header()->mutable_stamp() =
+      msgs::Convert(_now);
     this->dataPtr->pointMsg.set_is_dense(true);
 
     if (!this->dataPtr->xyzBuffer)
