@@ -14,38 +14,39 @@
  * limitations under the License.
  *
 */
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/pointcloud_packed.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/pointcloud_packed.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
-#include <gz/common/Console.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/msgs/Utility.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/msgs/Utility.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sensors/GpuLidarSensor.hh"
-#include "gz/sensors/SensorFactory.hh"
+#include "ignition/sensors/GpuLidarSensor.hh"
+#include "ignition/sensors/SensorFactory.hh"
 
-using namespace gz::sensors;
+using namespace ignition::sensors;
 
 /// \brief Private data for the GpuLidar class
-class gz::sensors::GpuLidarSensorPrivate
+class ignition::sensors::GpuLidarSensorPrivate
 {
   /// \brief Fill the point cloud packed message
   /// \param[in] _laserBuffer Lidar data buffer.
   public: void FillPointCloudMsg(const float *_laserBuffer);
 
   /// \brief Rendering camera
-  public: gz::rendering::GpuRaysPtr gpuRays;
+  public: ignition::rendering::GpuRaysPtr gpuRays;
 
   /// \brief Connection to the Manager's scene change event.
-  public: gz::common::ConnectionPtr sceneChangeConnection;
+  public: ignition::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief The point cloud message.
   public: msgs::PointCloudPacked pointMsg;
@@ -78,7 +79,7 @@ GpuLidarSensor::~GpuLidarSensor()
 }
 
 /////////////////////////////////////////////////
-void GpuLidarSensor::SetScene(gz::rendering::ScenePtr _scene)
+void GpuLidarSensor::SetScene(ignition::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->lidarMutex);
   // APIs make it possible for the scene pointer to change
@@ -94,7 +95,7 @@ void GpuLidarSensor::SetScene(gz::rendering::ScenePtr _scene)
 
 //////////////////////////////////////////////////
 void GpuLidarSensor::RemoveGpuRays(
-    gz::rendering::ScenePtr _scene)
+    ignition::rendering::ScenePtr _scene)
 {
   if (_scene)
   {
@@ -135,7 +136,7 @@ bool GpuLidarSensor::Load(const sdf::Sensor &_sdf)
   this->SetTopic(this->Topic() + "/points");
 
   this->dataPtr->pointPub =
-      this->dataPtr->node.Advertise<gz::msgs::PointCloudPacked>(
+      this->dataPtr->node.Advertise<ignition::msgs::PointCloudPacked>(
           this->Topic());
 
   if (!this->dataPtr->pointPub)
@@ -217,7 +218,13 @@ bool GpuLidarSensor::CreateLidar()
 }
 
 //////////////////////////////////////////////////
-bool GpuLidarSensor::Update(const gz::common::Time &_now)
+bool GpuLidarSensor::Update(const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool GpuLidarSensor::Update(const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("GpuLidarSensor::Update");
   if (!this->initialized)
@@ -253,11 +260,8 @@ bool GpuLidarSensor::Update(const gz::common::Time &_now)
   if (this->dataPtr->pointPub.HasConnections())
   {
     // Set the time stamp
-    this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_sec(
-        _now.sec);
-    this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_nsec(
-        _now.nsec);
-
+    *this->dataPtr->pointMsg.mutable_header()->mutable_stamp() =
+      msgs::Convert(_now);
     this->dataPtr->pointMsg.set_is_dense(true);
 
     this->dataPtr->FillPointCloudMsg(this->laserBuffer);
@@ -272,7 +276,7 @@ bool GpuLidarSensor::Update(const gz::common::Time &_now)
 }
 
 /////////////////////////////////////////////////
-gz::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
+ignition::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
           std::function<void(const float *_scan, unsigned int _width,
                   unsigned int _height, unsigned int _channels,
                   const std::string &/*_format*/)> _subscriber)
@@ -281,7 +285,7 @@ gz::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
 }
 
 /////////////////////////////////////////////////
-gz::rendering::GpuRaysPtr GpuLidarSensor::GpuRays() const
+ignition::rendering::GpuRaysPtr GpuLidarSensor::GpuRays() const
 {
   return this->dataPtr->gpuRays;
 }
@@ -293,13 +297,13 @@ bool GpuLidarSensor::IsHorizontal() const
 }
 
 //////////////////////////////////////////////////
-gz::math::Angle GpuLidarSensor::HFOV() const
+ignition::math::Angle GpuLidarSensor::HFOV() const
 {
   return this->dataPtr->gpuRays->HFOV();
 }
 
 //////////////////////////////////////////////////
-gz::math::Angle GpuLidarSensor::VFOV() const
+ignition::math::Angle GpuLidarSensor::VFOV() const
 {
   return this->dataPtr->gpuRays->VFOV();
 }
