@@ -14,29 +14,29 @@
  * limitations under the License.
  *
 */
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/imu.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/imu.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
-#include <gz/common/Profiler.hh>
-#include <gz/transport/Node.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sensors/ImuSensor.hh"
-#include "gz/sensors/Noise.hh"
-#include "gz/sensors/SensorFactory.hh"
-#include "gz/sensors/SensorTypes.hh"
+#include "ignition/sensors/ImuSensor.hh"
+#include "ignition/sensors/Noise.hh"
+#include "ignition/sensors/SensorFactory.hh"
+#include "ignition/sensors/SensorTypes.hh"
 
-using namespace gz;
+using namespace ignition;
 using namespace sensors;
 
 /// \brief Private data for ImuSensor
-class gz::sensors::ImuSensorPrivate
+class ignition::sensors::ImuSensorPrivate
 {
   /// \brief node to create publisher
   public: transport::Node node;
@@ -48,28 +48,32 @@ class gz::sensors::ImuSensorPrivate
   public: bool initialized = false;
 
   /// \brief Noise free linear acceleration
-  public: math::Vector3d linearAcc;
+  public: ignition::math::Vector3d linearAcc;
 
   /// \brief Noise free angular velocity.
-  public: math::Vector3d angularVel;
+  public: ignition::math::Vector3d angularVel;
 
   /// \brief transform to Imu orientation reference frame.
-  public: math::Quaterniond orientationReference;
+  public: ignition::math::Quaterniond orientationReference;
 
   /// \brief transform to Imu frame from Imu reference frame.
-  public: math::Quaterniond orientation;
+  public: ignition::math::Quaterniond orientation;
+
+  /// \brief True to publish orientation data.
+  public: bool orientationEnabled = true;
 
   /// \brief store gravity vector to be added to the IMU output.
-  public: math::Vector3d gravity;
+  public: ignition::math::Vector3d gravity;
 
   /// \brief World pose of the imu sensor
-  public: math::Pose3d worldPose;
+  public: ignition::math::Pose3d worldPose;
 
   /// \brief Flag for if time has been initialized
   public: bool timeInitialized = false;
 
   /// \brief Previous update time step.
-  public: common::Time prevStep { common::Time::Zero };
+  public: std::chrono::steady_clock::duration prevStep
+    {std::chrono::steady_clock::duration::zero()};
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
@@ -116,7 +120,7 @@ bool ImuSensor::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/imu");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<msgs::IMU>(this->Topic());
+      this->dataPtr->node.Advertise<ignition::msgs::IMU>(this->Topic());
 
   if (!this->dataPtr->pub)
   {
@@ -157,7 +161,14 @@ bool ImuSensor::Load(sdf::ElementPtr _sdf)
 }
 
 //////////////////////////////////////////////////
-bool ImuSensor::Update(const common::Time &_now)
+bool ImuSensor::Update(
+  const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool ImuSensor::Update(const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("ImuSensor::Update");
   if (!this->dataPtr->initialized)
@@ -176,7 +187,9 @@ bool ImuSensor::Update(const common::Time &_now)
   double dt;
   if (this->dataPtr->timeInitialized)
   {
-    dt = (_now - this->dataPtr->prevStep).Double();
+    auto delay = std::chrono::duration_cast<std::chrono::duration<float>>(
+        _now - this->dataPtr->prevStep);
+    dt = delay.count();
   }
   else
   {
@@ -204,21 +217,23 @@ bool ImuSensor::Update(const common::Time &_now)
   applyNoise(GYROSCOPE_Y_NOISE_RAD_S, this->dataPtr->angularVel.Y());
   applyNoise(GYROSCOPE_Z_NOISE_RAD_S, this->dataPtr->angularVel.Z());
 
-  // Set the IMU orientation
-  // imu orientation with respect to reference frame
-  this->dataPtr->orientation =
-      this->dataPtr->orientationReference.Inverse() *
-      this->dataPtr->worldPose.Rot();
-
   msgs::IMU msg;
-  msg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-  msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
+  *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
   msg.set_entity_name(this->Name());
   auto frame = msg.mutable_header()->add_data();
   frame->set_key("frame_id");
-  frame->add_value(this->FrameId());
+  frame->add_value(this->Name());
 
-  msgs::Set(msg.mutable_orientation(), this->dataPtr->orientation);
+  if (this->dataPtr->orientationEnabled)
+  {
+    // Set the IMU orientation
+    // imu orientation with respect to reference frame
+    this->dataPtr->orientation =
+        this->dataPtr->orientationReference.Inverse() *
+        this->dataPtr->worldPose.Rot();
+
+    msgs::Set(msg.mutable_orientation(), this->dataPtr->orientation);
+  }
   msgs::Set(msg.mutable_angular_velocity(), this->dataPtr->angularVel);
   msgs::Set(msg.mutable_linear_acceleration(), this->dataPtr->linearAcc);
 
@@ -278,6 +293,18 @@ math::Quaterniond ImuSensor::OrientationReference() const
   return this->dataPtr->orientationReference;
 }
 
+//////////////////////////////////////////////////
+void ImuSensor::SetOrientationEnabled(bool _enabled)
+{
+  this->dataPtr->orientationEnabled = _enabled;
+}
+
+//////////////////////////////////////////////////
+bool ImuSensor::OrientationEnabled() const
+{
+  return this->dataPtr->orientationEnabled;
+}
+
 //////////////////////////////////////////////////
 void ImuSensor::SetGravity(const math::Vector3d &_gravity)
 {
