@@ -15,38 +15,47 @@
  *
 */
 
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/image.pb.h>
-#include <gz/msgs/pointcloud_packed.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/image.pb.h>
+#include <ignition/msgs/pointcloud_packed.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
-#include <gz/common/Image.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/common/Image.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/math/Helpers.hh>
 
-#include <gz/rendering/Camera.hh>
-#include <gz/rendering/DepthCamera.hh>
+// TODO(louise) Remove these pragmas once ign-rendering is disabling the
+// warnings
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4251)
+#endif
+#include <ignition/rendering/Camera.hh>
+#include <ignition/rendering/DepthCamera.hh>
+#ifdef _WIN32
+#pragma warning(pop)
+#endif
 
-#include <gz/transport/Node.hh>
+#include <ignition/transport/Node.hh>
 
 #include <sdf/Sensor.hh>
 
-#include "gz/sensors/ImageGaussianNoiseModel.hh"
-#include "gz/sensors/ImageNoise.hh"
-#include "gz/sensors/RgbdCameraSensor.hh"
-#include "gz/sensors/RenderingEvents.hh"
-#include "gz/sensors/SensorFactory.hh"
+#include "ignition/sensors/ImageGaussianNoiseModel.hh"
+#include "ignition/sensors/ImageNoise.hh"
+#include "ignition/sensors/RgbdCameraSensor.hh"
+#include "ignition/sensors/RenderingEvents.hh"
+#include "ignition/sensors/SensorFactory.hh"
 
 #include "PointCloudUtil.hh"
 
 /// \brief Private data for RgbdCameraSensor
-class gz::sensors::RgbdCameraSensorPrivate
+class ignition::sensors::RgbdCameraSensorPrivate
 {
   /// \brief Depth data callback used to get the data from the sensor
   /// \param[in] _scan pointer to the data from the sensor
@@ -86,7 +95,7 @@ class gz::sensors::RgbdCameraSensorPrivate
   public: bool initialized = false;
 
   /// \brief Rendering camera
-  public: gz::rendering::DepthCameraPtr depthCamera;
+  public: ignition::rendering::DepthCameraPtr depthCamera;
 
   /// \brief Depth data buffer.
   public: float *depthBuffer = nullptr;
@@ -111,19 +120,19 @@ class gz::sensors::RgbdCameraSensorPrivate
   public: unsigned int channels = 4;
 
   /// \brief Pointer to an image to be published
-  public: gz::rendering::Image image;
+  public: ignition::rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
 
   /// \brief Connection from depth camera with new depth data
-  public: gz::common::ConnectionPtr depthConnection;
+  public: ignition::common::ConnectionPtr depthConnection;
 
   /// \brief Connection from depth camera with new point cloud data
-  public: gz::common::ConnectionPtr pointCloudConnection;
+  public: ignition::common::ConnectionPtr pointCloudConnection;
 
   /// \brief Connection to the Manager's scene change event.
-  public: gz::common::ConnectionPtr sceneChangeConnection;
+  public: ignition::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -139,7 +148,7 @@ class gz::sensors::RgbdCameraSensorPrivate
   public: PointCloudUtil pointsUtil;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace sensors;
 
 //////////////////////////////////////////////////
@@ -193,7 +202,7 @@ bool RgbdCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the 2d image publisher
   this->dataPtr->imagePub =
-      this->dataPtr->node.Advertise<msgs::Image>(
+      this->dataPtr->node.Advertise<ignition::msgs::Image>(
           this->Topic() + "/image");
   if (!this->dataPtr->imagePub)
   {
@@ -207,7 +216,7 @@ bool RgbdCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the depth image publisher
   this->dataPtr->depthPub =
-      this->dataPtr->node.Advertise<msgs::Image>(
+      this->dataPtr->node.Advertise<ignition::msgs::Image>(
           this->Topic() + "/depth_image");
   if (!this->dataPtr->depthPub)
   {
@@ -221,7 +230,7 @@ bool RgbdCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the point cloud publisher
   this->dataPtr->pointPub =
-      this->dataPtr->node.Advertise<msgs::PointCloudPacked>(
+      this->dataPtr->node.Advertise<ignition::msgs::PointCloudPacked>(
           this->Topic() + "/points");
   if (!this->dataPtr->pointPub)
   {
@@ -298,6 +307,8 @@ bool RgbdCameraSensor::CreateCameras()
     }
   }
 
+  this->dataPtr->depthCamera->SetVisibilityMask(cameraSdf->VisibilityMask());
+
   this->AddSensor(this->dataPtr->depthCamera);
 
   const std::map<SensorNoiseType, sdf::Noise> noises = {
@@ -372,7 +383,7 @@ bool RgbdCameraSensor::CreateCameras()
 }
 
 /////////////////////////////////////////////////
-void RgbdCameraSensor::SetScene(rendering::ScenePtr _scene)
+void RgbdCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -424,7 +435,13 @@ void RgbdCameraSensorPrivate::OnNewRgbPointCloud(const float *_scan,
 }
 
 //////////////////////////////////////////////////
-bool RgbdCameraSensor::Update(const common::Time &_now)
+bool RgbdCameraSensor::Update(const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool RgbdCameraSensor::Update(const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("RgbdCameraSensor::Update");
   if (!this->dataPtr->initialized)
@@ -449,17 +466,16 @@ bool RgbdCameraSensor::Update(const common::Time &_now)
   // create and publish the depthmessage
   if (this->dataPtr->depthPub.HasConnections())
   {
-    msgs::Image msg;
+    ignition::msgs::Image msg;
     msg.set_width(width);
     msg.set_height(height);
     msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
                rendering::PF_FLOAT32_R));
     msg.set_pixel_format_type(msgs::PixelFormatType::R_FLOAT32);
-    msg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-    msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
+    *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
     auto frame = msg.mutable_header()->add_data();
     frame->set_key("frame_id");
-    frame->add_value(this->FrameId());
+    frame->add_value(this->Name());
 
     std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
 
@@ -474,12 +490,12 @@ bool RgbdCameraSensor::Update(const common::Time &_now)
         if (this->dataPtr->hasDepthFarClip &&
             (this->dataPtr->depthBuffer[i] > this->dataPtr->depthFarClip))
         {
-          this->dataPtr->depthBuffer[i] = math::INF_D;
+          this->dataPtr->depthBuffer[i] = ignition::math::INF_D;
         }
         if (this->dataPtr->hasDepthNearClip &&
             (this->dataPtr->depthBuffer[i] < this->dataPtr->depthNearClip))
         {
-          this->dataPtr->depthBuffer[i] = -math::INF_D;
+          this->dataPtr->depthBuffer[i] = -ignition::math::INF_D;
         }
       }
     }
@@ -508,11 +524,9 @@ bool RgbdCameraSensor::Update(const common::Time &_now)
     // publish point cloud msg
     if (this->dataPtr->pointPub.HasConnections())
     {
+      *this->dataPtr->pointMsg.mutable_header()->mutable_stamp() =
+        msgs::Convert(_now);
       // Set the time stamp
-      this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_sec(
-          _now.sec);
-      this->dataPtr->pointMsg.mutable_header()->mutable_stamp()->set_nsec(
-          _now.nsec);
       this->dataPtr->pointMsg.set_is_dense(true);
 
       if ((this->dataPtr->hasDepthNearClip || this->dataPtr->hasDepthFarClip)
@@ -564,17 +578,16 @@ bool RgbdCameraSensor::Update(const common::Time &_now)
 
       unsigned char *data = this->dataPtr->image.Data<unsigned char>();
 
-      msgs::Image msg;
+      ignition::msgs::Image msg;
       msg.set_width(width);
       msg.set_height(height);
       msg.set_step(width * rendering::PixelUtil::BytesPerPixel(
           rendering::PF_R8G8B8));
       msg.set_pixel_format_type(msgs::PixelFormatType::RGB_INT8);
-      msg.mutable_header()->mutable_stamp()->set_sec(_now.sec);
-      msg.mutable_header()->mutable_stamp()->set_nsec(_now.nsec);
+      *msg.mutable_header()->mutable_stamp() = msgs::Convert(_now);
       auto frame = msg.mutable_header()->add_data();
       frame->set_key("frame_id");
-      frame->add_value(this->FrameId());
+      frame->add_value(this->Name());
       msg.set_data(data, rendering::PixelUtil::MemorySize(rendering::PF_R8G8B8,
         width, height));
 
