@@ -15,20 +15,21 @@
  *
 */
 
-#include "gz/sensors/Sensor.hh"
+#include "ignition/sensors/Sensor.hh"
 
 #include <chrono>
 #include <map>
 #include <vector>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/transport/Node.hh>
-#include <gz/transport/TopicUtils.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/msgs/double.pb.h>
+#include <ignition/transport/Node.hh>
+#include <ignition/transport/TopicUtils.hh>
 
-using namespace gz::sensors;
+using namespace ignition::sensors;
 
-class gz::sensors::SensorPrivate
+class ignition::sensors::SensorPrivate
 {
   /// \brief Populates fields from a <sensor> DOM
   public: bool PopulateFromSDF(const sdf::Sensor &_sdf);
@@ -42,6 +43,14 @@ class gz::sensors::SensorPrivate
   /// \param[in] _now Current simulation time.
   public: void PublishMetrics(const std::chrono::duration<double> &_now);
 
+  /// \brief Set the rate on which the sensor should publish its data. This
+  /// method doesn't allow to set a higher rate than what is in the SDF.
+  /// \param[in] _rate Maximum rate of the sensor. It is capped by the
+  /// <update_rate> value from SDF, and zero is allowed only when zero is also
+  /// in SDF.
+  /// \return True if a valid topic was set.
+  public: void SetRate(const ignition::msgs::Double &_rate);
+
   /// \brief id given to sensor when constructed
   public: SensorId id;
 
@@ -58,16 +67,22 @@ class gz::sensors::SensorPrivate
   public: std::string topic;
 
   /// \brief Pose of the sensor
-  public: gz::math::Pose3d pose;
+  public: ignition::math::Pose3d pose;
 
   /// \brief Flag to enable publishing performance metrics.
   public: bool enableMetrics{false};
 
-  /// \brief How many times the sensor will generate data per second
+  /// \brief How many times the sensor will generate data per second (value from
+  /// SDF.
+  public: double sdfUpdateRate = 0.0;
+
+  /// \brief How many times the sensor will generate data per second (currently
+  /// used value).
   public: double updateRate = 0.0;
 
   /// \brief What sim time should this sensor update at
-  public: gz::common::Time nextUpdateTime;
+  public: std::chrono::steady_clock::duration nextUpdateTime
+    {std::chrono::steady_clock::duration::zero()};
 
   /// \brief Last steady clock time reading from last Update call.
   public: std::chrono::time_point<std::chrono::steady_clock> lastRealTime;
@@ -76,10 +91,10 @@ class gz::sensors::SensorPrivate
   public: std::chrono::duration<double> lastUpdateTime{0};
 
   /// \brief Transport node.
-  public: gz::transport::Node node;
+  public: ignition::transport::Node node;
 
   /// \brief Publishes the PerformanceSensorMetrics message.
-  public: gz::transport::Node::Publisher performanceSensorMetricsPub;
+  public: ignition::transport::Node::Publisher performanceSensorMetricsPub;
 
   /// \brief SDF element with sensor information.
   public: sdf::ElementPtr sdf = nullptr;
@@ -91,9 +106,6 @@ class gz::sensors::SensorPrivate
   /// A map is used so that a single sensor can have multiple sensor
   /// streams each with a sequence counter.
   public: std::map<std::string, uint64_t> sequences;
-
-  /// \brief frame id
-  public: std::string frame_id;
 };
 
 SensorId SensorPrivate::idCounter = 0;
@@ -124,19 +136,6 @@ bool SensorPrivate::PopulateFromSDF(const sdf::Sensor &_sdf)
       return false;
   }
 
-  sdf::ElementPtr element = _sdf.Element();
-  if (element)
-  {
-    if (element->HasElement("ignition_frame_id"))
-    {
-      this->frame_id = element->Get<std::string>("ignition_frame_id");
-    }
-    else
-    {
-      this->frame_id = this->name;
-    }
-  }
-
   // Try resolving the pose first, and only use the raw pose if that fails
   auto semPose = _sdf.SemanticPose();
   sdf::Errors errors = semPose.Resolve(this->pose);
@@ -145,7 +144,7 @@ bool SensorPrivate::PopulateFromSDF(const sdf::Sensor &_sdf)
     this->pose = _sdf.RawPose();
   }
 
-  this->updateRate = _sdf.UpdateRate();
+  this->sdfUpdateRate = this->updateRate = _sdf.UpdateRate();
 
   this->enableMetrics = _sdf.EnableMetrics();
   return true;
@@ -161,6 +160,7 @@ Sensor::Sensor() :
 //////////////////////////////////////////////////
 bool Sensor::Init()
 {
+  this->dataPtr->nextUpdateTime = std::chrono::steady_clock::duration::zero();
   return true;
 }
 
@@ -172,7 +172,25 @@ Sensor::~Sensor()
 //////////////////////////////////////////////////
 bool Sensor::Load(const sdf::Sensor &_sdf)
 {
-  return this->dataPtr->PopulateFromSDF(_sdf);
+  const bool success = this->dataPtr->PopulateFromSDF(_sdf);
+  if (!success)
+    return false;
+
+  auto sensorTopic = this->Topic();
+  if (sensorTopic.empty())
+    sensorTopic = "/" + this->Name();
+
+  const auto rateTopic = sensorTopic + "/set_rate";
+
+  if (!this->dataPtr->node.Advertise(rateTopic,
+    &SensorPrivate::SetRate, this->dataPtr.get()))
+  {
+    ignerr << "Unable to create service server on topic["
+           << rateTopic << "].\n";
+    return false;
+  }
+
+  return true;
 }
 
 //////////////////////////////////////////////////
@@ -187,7 +205,7 @@ bool Sensor::Load(sdf::ElementPtr _sdf)
 
   sdf::Sensor sdfSensor;
   sdfSensor.Load(_sdf);
-  return this->dataPtr->PopulateFromSDF(sdfSensor);
+  return this->Load(sdfSensor);
 }
 
 //////////////////////////////////////////////////
@@ -208,18 +226,6 @@ std::string Sensor::Name() const
   return this->dataPtr->name;
 }
 
-//////////////////////////////////////////////////
-std::string Sensor::FrameId() const
-{
-  return this->dataPtr->frame_id;
-}
-
-//////////////////////////////////////////////////
-void Sensor::SetFrameId(const std::string &_frameId)
-{
-  this->dataPtr->frame_id = _frameId;
-}
-
 //////////////////////////////////////////////////
 std::string Sensor::Topic() const
 {
@@ -320,7 +326,43 @@ void SensorPrivate::PublishMetrics(const std::chrono::duration<double> &_now)
 }
 
 //////////////////////////////////////////////////
-gz::math::Pose3d Sensor::Pose() const
+void SensorPrivate::SetRate(const ignition::msgs::Double &_rate)
+{
+  auto rate = _rate.data();
+  if (rate < 0.0)
+    rate = 0.0;
+
+  // if SDF has zero, any value can be set; for non-zero SDF values, we need to
+  // check whether they are in bounds, i.e. greater than zero and lower or equal
+  // to the SDF value
+  if (!ignition::math::lessOrNearEqual(this->sdfUpdateRate, 0.0))
+  {
+    if (ignition::math::lessOrNearEqual(rate, 0.0))
+    {
+      ignerr << "Cannot set update rate of sensor " << this->name << " to zero "
+             << "because the <update_rate> SDF element is non-zero."
+             << std::endl;
+      return;
+    }
+    // apply the upper rate limit from SDF
+    else if (!ignition::math::lessOrNearEqual(rate, this->sdfUpdateRate))
+    {
+      ignerr << "Trying to set update rate of sensor " << this->name << " to "
+             << rate << ", but the maximum rate in <update_rate> SDF element "
+             << "is " << this->sdfUpdateRate << ". Ignoring the request."
+             << std::endl;
+      return;
+    }
+  }
+
+  igndbg << "Setting update rate of sensor " << this->name << " to " << rate
+         << " Hz" << std::endl;
+
+  this->updateRate = rate;
+}
+
+//////////////////////////////////////////////////
+ignition::math::Pose3d Sensor::Pose() const
 {
   return this->dataPtr->pose;
 }
@@ -338,7 +380,7 @@ void Sensor::SetParent(const std::string &_parent)
 }
 
 //////////////////////////////////////////////////
-void Sensor::SetPose(const gz::math::Pose3d &_pose)
+void Sensor::SetPose(const ignition::math::Pose3d &_pose)
 {
   this->dataPtr->pose = _pose;
 }
@@ -363,7 +405,7 @@ void Sensor::SetUpdateRate(const double _hz)
 }
 
 //////////////////////////////////////////////////
-bool Sensor::Update(const gz::common::Time &_now,
+bool Sensor::Update(const std::chrono::steady_clock::duration &_now,
                   const bool _force)
 {
   IGN_PROFILE("Sensor::Update");
@@ -382,13 +424,15 @@ bool Sensor::Update(const gz::common::Time &_now,
   // Publish metrics
   if (this->EnableMetrics())
   {
-    this->PublishMetrics(std::chrono::duration<double>(_now.Double()));
+    auto secs = std::chrono::duration_cast<std::chrono::duration<double>>(_now);
+    this->PublishMetrics(secs);
   }
 
   if (!_force && this->dataPtr->updateRate > 0.0)
   {
     // Update the time the plugin should be loaded
-    gz::common::Time delta(1.0 / this->dataPtr->updateRate);
+    auto delta = std::chrono::duration_cast< std::chrono::milliseconds>
+      (std::chrono::duration< double >(1.0 / this->dataPtr->updateRate));
     this->dataPtr->nextUpdateTime += delta;
   }
 
@@ -396,13 +440,34 @@ bool Sensor::Update(const gz::common::Time &_now,
 }
 
 //////////////////////////////////////////////////
-gz::common::Time Sensor::NextUpdateTime() const
+bool Sensor::Update(const ignition::common::Time &_now, const bool _force)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec), _force);
+}
+
+//////////////////////////////////////////////////
+std::chrono::steady_clock::duration Sensor::NextDataUpdateTime() const
 {
   return this->dataPtr->nextUpdateTime;
 }
 
+//////////////////////////////////////////////////
+ignition::common::Time Sensor::NextUpdateTime() const
+{
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
+  std::pair<uint64_t, uint64_t> secNsec =
+    math::durationToSecNsec(this->dataPtr->nextUpdateTime);
+  return common::Time(secNsec.first, secNsec.second);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
+}
+
 /////////////////////////////////////////////////
-void Sensor::AddSequence(gz::msgs::Header *_msg,
+void Sensor::AddSequence(ignition::msgs::Header *_msg,
                          const std::string &_seqKey)
 {
   std::string value = "0";
@@ -426,7 +491,7 @@ void Sensor::AddSequence(gz::msgs::Header *_msg,
   }
 
   // Otherwise, add the sequence key-value pair.
-  gz::msgs::Header::Map *map = _msg->add_data();
+  ignition::msgs::Header::Map *map = _msg->add_data();
   map->set_key("seq");
   map->add_value(value);
 }
