@@ -15,36 +15,36 @@
  *
 */
 
-#if defined(_MSC_VER)
-  #pragma warning(push)
-  #pragma warning(disable: 4005)
-  #pragma warning(disable: 4251)
+#ifdef _WIN32
+#pragma warning(push)
+#pragma warning(disable: 4005)
+#pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/image.pb.h>
-#if defined(_MSC_VER)
-  #pragma warning(pop)
+#include <ignition/msgs/image.pb.h>
+#ifdef _WIN32
+#pragma warning(pop)
 #endif
 
 #include <algorithm>
 #include <mutex>
 
-#include <gz/common/Console.hh>
-#include <gz/common/Image.hh>
-#include <gz/common/Profiler.hh>
-#include <gz/common/SystemPaths.hh>
+#include <ignition/common/Console.hh>
+#include <ignition/common/Image.hh>
+#include <ignition/common/Profiler.hh>
+#include <ignition/common/SystemPaths.hh>
 
-#include <gz/math/Angle.hh>
-#include <gz/math/Helpers.hh>
+#include <ignition/math/Angle.hh>
+#include <ignition/math/Helpers.hh>
 
-#include <gz/transport/Node.hh>
+#include <ignition/transport/Node.hh>
 
-#include "gz/sensors/ThermalCameraSensor.hh"
-#include "gz/sensors/ImageGaussianNoiseModel.hh"
-#include "gz/sensors/RenderingEvents.hh"
-#include "gz/sensors/SensorFactory.hh"
+#include "ignition/sensors/ThermalCameraSensor.hh"
+#include "ignition/sensors/ImageGaussianNoiseModel.hh"
+#include "ignition/sensors/RenderingEvents.hh"
+#include "ignition/sensors/SensorFactory.hh"
 
 /// \brief Private data for ThermalCameraSensor
-class gz::sensors::ThermalCameraSensorPrivate
+class ignition::sensors::ThermalCameraSensorPrivate
 {
   /// \brief Save an image
   /// \param[in] _data the image data to be saved
@@ -56,7 +56,7 @@ class gz::sensors::ThermalCameraSensorPrivate
   /// of the path was not possible.
   /// \sa ImageSaver
   public: bool SaveImage(const uint16_t *_data, unsigned int _width,
-    unsigned int _height, gz::common::Image::PixelFormatType _format);
+    unsigned int _height, ignition::common::Image::PixelFormatType _format);
 
   /// \brief Helper function to convert temperature data to thermal image
   /// \param[in] _data temperature data
@@ -73,11 +73,14 @@ class gz::sensors::ThermalCameraSensorPrivate
   public: bool initialized = false;
 
   /// \brief Rendering camera
-  public: gz::rendering::ThermalCameraPtr thermalCamera;
+  public: ignition::rendering::ThermalCameraPtr thermalCamera;
 
   /// \brief Thermal data buffer.
   public: uint16_t *thermalBuffer = nullptr;
 
+  /// \brief Thermal data buffer 8 bit.
+  public: unsigned char *thermalBuffer8Bit = nullptr;
+
   /// \brief Thermal data buffer used when saving image.
   public: unsigned char *imgThermalBuffer = nullptr;
 
@@ -86,21 +89,21 @@ class gz::sensors::ThermalCameraSensorPrivate
       math::Vector2i::Zero;
 
   /// \brief Pointer to an image to be published
-  public: gz::rendering::Image image;
+  public: ignition::rendering::Image image;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
 
   /// \brief Event that is used to trigger callbacks when a new image
   /// is generated
-  public: gz::common::EventT<
-          void(const gz::msgs::Image &)> imageEvent;
+  public: ignition::common::EventT<
+          void(const ignition::msgs::Image &)> imageEvent;
 
   /// \brief Connection from thermal camera with thermal data
-  public: gz::common::ConnectionPtr thermalConnection;
+  public: ignition::common::ConnectionPtr thermalConnection;
 
   /// \brief Connection to the Manager's scene change event.
-  public: gz::common::ConnectionPtr sceneChangeConnection;
+  public: ignition::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Just a mutex for thread safety
   public: std::mutex mutex;
@@ -133,16 +136,16 @@ class gz::sensors::ThermalCameraSensorPrivate
   public: float ambientRange = 0.0;
 
   /// \brief Min temperature the sensor can detect
-  public: float minTemp = -gz::math::INF_F;
+  public: float minTemp = -ignition::math::INF_F;
 
   /// \brief Max temperature the sensor can detect
-  public: float maxTemp = gz::math::INF_F;
+  public: float maxTemp = ignition::math::INF_F;
 
   /// \brief Linear resolution. Defaults to 10mK
   public: float resolution = 0.01f;
 };
 
-using namespace gz;
+using namespace ignition;
 using namespace sensors;
 
 //////////////////////////////////////////////////
@@ -158,6 +161,9 @@ ThermalCameraSensor::~ThermalCameraSensor()
   if (this->dataPtr->thermalBuffer)
     delete [] this->dataPtr->thermalBuffer;
 
+  if (this->dataPtr->thermalBuffer8Bit)
+    delete[] this->dataPtr->thermalBuffer8Bit;
+
   if (this->dataPtr->imgThermalBuffer)
     delete[] this->dataPtr->imgThermalBuffer;
 }
@@ -204,7 +210,7 @@ bool ThermalCameraSensor::Load(const sdf::Sensor &_sdf)
 
   // Create the thermal image publisher
   this->dataPtr->thermalPub =
-      this->dataPtr->node.Advertise<msgs::Image>(
+      this->dataPtr->node.Advertise<ignition::msgs::Image>(
           this->Topic());
 
   if (!this->dataPtr->thermalPub)
@@ -248,6 +254,8 @@ bool ThermalCameraSensor::CreateCamera()
   int width = cameraSdf->ImageWidth();
   int height = cameraSdf->ImageHeight();
 
+  sdf::PixelFormatType pixelFormat = cameraSdf->PixelFormat();
+
   double farPlane = cameraSdf->FarClip();
   double nearPlane = cameraSdf->NearClip();
 
@@ -257,8 +265,34 @@ bool ThermalCameraSensor::CreateCamera()
       this->Name());
   this->dataPtr->thermalCamera->SetImageWidth(width);
   this->dataPtr->thermalCamera->SetImageHeight(height);
+  switch (pixelFormat)
+  {
+    case sdf::PixelFormatType::L_INT8:
+    {
+      this->dataPtr->thermalCamera->SetImageFormat(rendering::PF_L8);
+      // sanity check for resolution. The default resolution 10mK is too high
+      // for 8 bit cameras since it can only capture a temperature range of
+      // 0 to 2.55 degrees Kelvin ((2^8-1) * 0.01 = 2.55).
+      if (this->dataPtr->resolution < 1.0)
+      {
+        ignwarn << "8 bit thermal camera image format selected. "
+                << "The temperature linear resolution needs to be higher "
+                << "than 1.0. Defaulting to 3.0, output range = [0, 255*3] K"
+                << std::endl;
+        this->dataPtr->resolution = 3.0;
+      }
+      break;
+    }
+    // default to 16 bit if format is not recognized
+    case sdf::PixelFormatType::L_INT16:
+    default:
+      this->dataPtr->thermalCamera->SetImageFormat(rendering::PF_L16);
+      break;
+  }
   this->dataPtr->thermalCamera->SetNearClipPlane(nearPlane);
   this->dataPtr->thermalCamera->SetFarClipPlane(farPlane);
+  this->dataPtr->thermalCamera->SetVisibilityMask(
+      cameraSdf->VisibilityMask());
 
   this->dataPtr->thermalCamera->SetAmbientTemperature(this->dataPtr->ambient);
   this->dataPtr->thermalCamera->SetMinTemperature(this->dataPtr->minTemp);
@@ -350,13 +384,13 @@ rendering::ThermalCameraPtr ThermalCameraSensor::ThermalCamera()
 
 /////////////////////////////////////////////////
 common::ConnectionPtr ThermalCameraSensor::ConnectImageCallback(
-    std::function<void(const msgs::Image &)> _callback)
+    std::function<void(const ignition::msgs::Image &)> _callback)
 {
   return this->dataPtr->imageEvent.Connect(_callback);
 }
 
 /////////////////////////////////////////////////
-void ThermalCameraSensor::SetScene(rendering::ScenePtr _scene)
+void ThermalCameraSensor::SetScene(ignition::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
   // APIs make it possible for the scene pointer to change
@@ -372,7 +406,14 @@ void ThermalCameraSensor::SetScene(rendering::ScenePtr _scene)
 }
 
 //////////////////////////////////////////////////
-bool ThermalCameraSensor::Update(const common::Time &_now)
+bool ThermalCameraSensor::Update(const ignition::common::Time &_now)
+{
+  return this->Update(math::secNsecToDuration(_now.sec, _now.nsec));
+}
+
+//////////////////////////////////////////////////
+bool ThermalCameraSensor::Update(
+  const std::chrono::steady_clock::duration &_now)
 {
   IGN_PROFILE("ThermalCameraSensor::Update");
   if (!this->dataPtr->initialized)
@@ -400,26 +441,54 @@ bool ThermalCameraSensor::Update(const common::Time &_now)
   unsigned int width = this->dataPtr->thermalCamera->ImageWidth();
   unsigned int height = this->dataPtr->thermalCamera->ImageHeight();
 
+
   auto commonFormat = common::Image::L_INT16;
   auto msgsFormat = msgs::PixelFormatType::L_INT16;
+  auto renderingFormat = rendering::PF_L16;
+
+  if (this->dataPtr->thermalCamera->ImageFormat() == rendering::PF_L8)
+  {
+    commonFormat = common::Image::L_INT8;
+    msgsFormat = msgs::PixelFormatType::L_INT8;
+    renderingFormat = rendering::PF_L8;
+  }
 
   // create message
   this->dataPtr->thermalMsg.set_width(width);
   this->dataPtr->thermalMsg.set_height(height);
   this->dataPtr->thermalMsg.set_step(
-      width * rendering::PixelUtil::BytesPerPixel(rendering::PF_L16));
+      width * rendering::PixelUtil::BytesPerPixel(renderingFormat));
   this->dataPtr->thermalMsg.set_pixel_format_type(msgsFormat);
   auto stamp = this->dataPtr->thermalMsg.mutable_header()->mutable_stamp();
-  stamp->set_sec(_now.sec);
-  stamp->set_nsec(_now.nsec);
+  *stamp = msgs::Convert(_now);
   auto frame = this->dataPtr->thermalMsg.mutable_header()->add_data();
   frame->set_key("frame_id");
-  frame->add_value(this->FrameId());
+  frame->add_value(this->Name());
 
   std::lock_guard<std::mutex> lock(this->dataPtr->mutex);
-  this->dataPtr->thermalMsg.set_data(this->dataPtr->thermalBuffer,
-      rendering::PixelUtil::MemorySize(rendering::PF_L16,
-      width, height));
+
+  // \todo(anyone) once ign-rendering supports an image event with unsigned char
+  // data type, we can remove this check that copies uint16_t data to char array
+  if (this->dataPtr->thermalCamera->ImageFormat() == rendering::PF_L8)
+  {
+    unsigned int len = width * height;
+    if (!this->dataPtr->thermalBuffer8Bit)
+      this->dataPtr->thermalBuffer8Bit = new unsigned char[len];
+    for (unsigned int i = 0; i < len; ++i)
+    {
+      this->dataPtr->thermalBuffer8Bit[i] =
+          static_cast<uint8_t>(this->dataPtr->thermalBuffer[i]);
+    }
+    this->dataPtr->thermalMsg.set_data(this->dataPtr->thermalBuffer8Bit,
+        rendering::PixelUtil::MemorySize(renderingFormat,
+        width, height));
+  }
+  else
+  {
+    this->dataPtr->thermalMsg.set_data(this->dataPtr->thermalBuffer,
+        rendering::PixelUtil::MemorySize(renderingFormat,
+        width, height));
+  }
 
   // publish the camera info message
   this->PublishInfo(_now);
@@ -550,19 +619,19 @@ bool ThermalCameraSensorPrivate::ConvertTemperatureToImage(
 //////////////////////////////////////////////////
 bool ThermalCameraSensorPrivate::SaveImage(const uint16_t *_data,
     unsigned int _width, unsigned int _height,
-    common::Image::PixelFormatType /*_format*/)
+    ignition::common::Image::PixelFormatType /*_format*/)
 {
   // Attempt to create the directory if it doesn't exist
-  if (!common::isDirectory(this->saveImagePath))
+  if (!ignition::common::isDirectory(this->saveImagePath))
   {
-    if (!common::createDirectories(this->saveImagePath))
+    if (!ignition::common::createDirectories(this->saveImagePath))
       return false;
   }
 
   if (_width == 0 || _height == 0)
     return false;
 
-  common::Image localImage;
+  ignition::common::Image localImage;
 
   if (static_cast<int>(_width) != this->imgThermalBufferSize.X() ||
       static_cast<int>(_height) != this->imgThermalBufferSize.Y())
@@ -583,7 +652,7 @@ bool ThermalCameraSensorPrivate::SaveImage(const uint16_t *_data,
   localImage.SetFromData(this->imgThermalBuffer, _width, _height,
       common::Image::RGB_INT8);
   localImage.SavePNG(
-      common::joinPaths(this->saveImagePath, filename));
+      ignition::common::joinPaths(this->saveImagePath, filename));
 
   return true;
 }
