@@ -19,16 +19,16 @@
 
 #include <sdf/sdf.hh>
 
-#include <gz/math/Helpers.hh>
-#include <gz/sensors/AirPressureSensor.hh>
-#include <gz/sensors/SensorFactory.hh>
+#include <ignition/math/Helpers.hh>
+#include <ignition/sensors/AirPressureSensor.hh>
+#include <ignition/sensors/SensorFactory.hh>
 
 #include "test_config.h"  // NOLINT(build/include)
 #include "TransportTestTools.hh"
 
 /// \brief Helper function to create an air pressure sdf element
 sdf::ElementPtr AirPressureToSdf(const std::string &_name,
-    const gz::math::Pose3d &_pose, const double _updateRate,
+    const ignition::math::Pose3d &_pose, const double _updateRate,
     const std::string &_topic, const bool _alwaysOn,
     const bool _visualize)
 {
@@ -60,7 +60,7 @@ sdf::ElementPtr AirPressureToSdf(const std::string &_name,
 
 /// \brief Helper function to create an air pressure sdf element with noise
 sdf::ElementPtr AirPressureToSdfWithNoise(const std::string &_name,
-    const gz::math::Pose3d &_pose, const double _updateRate,
+    const ignition::math::Pose3d &_pose, const double _updateRate,
     const std::string &_topic, const bool _alwaysOn,
     const bool _visualize, double _mean, double _stddev, double _bias)
 {
@@ -105,7 +105,7 @@ class AirPressureSensorTest: public testing::Test
   // Documentation inherited
   protected: void SetUp() override
   {
-    gz::common::Console::SetVerbosity(4);
+    ignition::common::Console::SetVerbosity(4);
   }
 };
 
@@ -121,8 +121,8 @@ TEST_F(AirPressureSensorTest, CreateAirPressure)
   const bool visualize = 1;
 
   // Create sensor SDF
-  gz::math::Pose3d sensorPose(gz::math::Vector3d(0.25, 0.0, 0.5),
-      gz::math::Quaterniond::Identity);
+  ignition::math::Pose3d sensorPose(ignition::math::Vector3d(0.25, 0.0, 0.5),
+      ignition::math::Quaterniond::Identity);
   sdf::ElementPtr airPressureSdf = AirPressureToSdf(name, sensorPose,
         updateRate, topic, alwaysOn, visualize);
 
@@ -130,17 +130,17 @@ TEST_F(AirPressureSensorTest, CreateAirPressure)
       sensorPose, updateRate, topicNoise, alwaysOn, visualize, 1.0, 0.2, 10.0);
 
   // create the sensor using sensor factory
-  gz::sensors::SensorFactory sf;
-  std::unique_ptr<gz::sensors::AirPressureSensor> sensor =
-      sf.CreateSensor<gz::sensors::AirPressureSensor>(airPressureSdf);
+  ignition::sensors::SensorFactory sf;
+  std::unique_ptr<ignition::sensors::AirPressureSensor> sensor =
+      sf.CreateSensor<ignition::sensors::AirPressureSensor>(airPressureSdf);
   ASSERT_NE(nullptr, sensor);
 
   EXPECT_EQ(name, sensor->Name());
   EXPECT_EQ(topic, sensor->Topic());
   EXPECT_DOUBLE_EQ(updateRate, sensor->UpdateRate());
 
-  std::unique_ptr<gz::sensors::AirPressureSensor> sensorNoise =
-      sf.CreateSensor<gz::sensors::AirPressureSensor>(
+  std::unique_ptr<ignition::sensors::AirPressureSensor> sensorNoise =
+      sf.CreateSensor<ignition::sensors::AirPressureSensor>(
           airPressureSdfNoise);
   ASSERT_NE(nullptr, sensorNoise);
 
@@ -161,8 +161,8 @@ TEST_F(AirPressureSensorTest, SensorReadings)
   const bool visualize = 1;
 
   // Create sensor SDF
-  gz::math::Pose3d sensorPose(gz::math::Vector3d(0.25, 0.0, 0.5),
-      gz::math::Quaterniond::Identity);
+  ignition::math::Pose3d sensorPose(ignition::math::Vector3d(0.25, 0.0, 0.5),
+      ignition::math::Quaterniond::Identity);
   sdf::ElementPtr airPressureSdf = AirPressureToSdf(name, sensorPose,
         updateRate, topic, alwaysOn, visualize);
 
@@ -171,19 +171,19 @@ TEST_F(AirPressureSensorTest, SensorReadings)
 
   // create the sensor using sensor factory
   // try creating without specifying the sensor type and then cast it
-  gz::sensors::SensorFactory sf;
-  std::unique_ptr<gz::sensors::Sensor> s =
+  ignition::sensors::SensorFactory sf;
+  std::unique_ptr<ignition::sensors::Sensor> s =
       sf.CreateSensor(airPressureSdf);
-  std::unique_ptr<gz::sensors::AirPressureSensor> sensor(
-      dynamic_cast<gz::sensors::AirPressureSensor *>(s.release()));
+  std::unique_ptr<ignition::sensors::AirPressureSensor> sensor(
+      dynamic_cast<ignition::sensors::AirPressureSensor *>(s.release()));
 
   // Make sure the above dynamic cast worked.
   ASSERT_NE(nullptr, sensor);
 
-  std::unique_ptr<gz::sensors::Sensor> sNoise =
+  std::unique_ptr<ignition::sensors::Sensor> sNoise =
       sf.CreateSensor(airPressureSdfNoise);
-  std::unique_ptr<gz::sensors::AirPressureSensor> sensorNoise(
-      dynamic_cast<gz::sensors::AirPressureSensor *>(sNoise.release()));
+  std::unique_ptr<ignition::sensors::AirPressureSensor> sensorNoise(
+      dynamic_cast<ignition::sensors::AirPressureSensor *>(sNoise.release()));
 
   // Make sure the above dynamic cast worked.
   ASSERT_NE(nullptr, sensorNoise);
@@ -202,11 +202,11 @@ TEST_F(AirPressureSensorTest, SensorReadings)
   EXPECT_DOUBLE_EQ(vertRef, sensorNoise->ReferenceAltitude());
 
   sensor->SetPose(sensorNoise->Pose() +
-      gz::math::Pose3d(0, 0, 1.5, 0, 0, 0));
+      ignition::math::Pose3d(0, 0, 1.5, 0, 0, 0));
 
   // verify msg received on the topic
-  WaitForMessageTestHelper<gz::msgs::FluidPressure> msgHelper(topic);
-  sensor->Update(gz::common::Time(1, 0));
+  WaitForMessageTestHelper<ignition::msgs::FluidPressure> msgHelper(topic);
+  sensor->Update(std::chrono::steady_clock::duration(std::chrono::seconds(1)));
   EXPECT_TRUE(msgHelper.WaitForMessage()) << msgHelper;
   auto msg = msgHelper.Message();
   EXPECT_EQ(1, msg.header().stamp().sec());
@@ -215,14 +215,15 @@ TEST_F(AirPressureSensorTest, SensorReadings)
   EXPECT_DOUBLE_EQ(0.0, msg.variance());
 
   // verify msg with noise received on the topic
-  WaitForMessageTestHelper<gz::msgs::FluidPressure>
+  WaitForMessageTestHelper<ignition::msgs::FluidPressure>
     msgHelperNoise(topicNoise);
-  sensorNoise->Update(gz::common::Time(1, 0));
+  sensorNoise->Update(std::chrono::steady_clock::duration(
+      std::chrono::seconds(1)));
   EXPECT_TRUE(msgHelperNoise.WaitForMessage()) << msgHelperNoise;
   auto msgNoise = msgHelperNoise.Message();
   EXPECT_EQ(1, msg.header().stamp().sec());
   EXPECT_EQ(0, msg.header().stamp().nsec());
-  EXPECT_FALSE(gz::math::equal(101288.9657925308, msgNoise.pressure()));
+  EXPECT_FALSE(ignition::math::equal(101288.9657925308, msgNoise.pressure()));
   EXPECT_DOUBLE_EQ(sqrt(0.2), msgNoise.variance());
 }
 
@@ -233,10 +234,10 @@ TEST_F(AirPressureSensorTest, Topic)
   const double updateRate = 30;
   const bool alwaysOn = 1;
   const bool visualize = 1;
-  auto sensorPose = gz::math::Pose3d();
+  auto sensorPose = ignition::math::Pose3d();
 
   // Factory
-  gz::sensors::SensorFactory factory;
+  ignition::sensors::SensorFactory factory;
 
   // Default topic
   {
@@ -248,7 +249,7 @@ TEST_F(AirPressureSensorTest, Topic)
     EXPECT_NE(nullptr, sensor);
 
     auto airPressure =
-        dynamic_cast<gz::sensors::AirPressureSensor *>(sensor.release());
+        dynamic_cast<ignition::sensors::AirPressureSensor *>(sensor.release());
     ASSERT_NE(nullptr, airPressure);
 
     EXPECT_EQ("/air_pressure", airPressure->Topic());
@@ -264,7 +265,7 @@ TEST_F(AirPressureSensorTest, Topic)
     EXPECT_NE(nullptr, sensor);
 
     auto airPressure =
-        dynamic_cast<gz::sensors::AirPressureSensor *>(sensor.release());
+        dynamic_cast<ignition::sensors::AirPressureSensor *>(sensor.release());
     ASSERT_NE(nullptr, airPressure);
 
     EXPECT_EQ("/topic_with_spaces/characters", airPressure->Topic());
