@@ -22,16 +22,16 @@
 #pragma warning(disable: 4005)
 #pragma warning(disable: 4251)
 #endif
-#include <gz/msgs/camera_info.pb.h>
+#include <ignition/msgs/camera_info.pb.h>
 #include <ignition/msgs.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
 
-#include <gz/common/Filesystem.hh>
-#include <gz/common/Event.hh>
-#include <gz/sensors/Manager.hh>
-#include <gz/sensors/RgbdCameraSensor.hh>
+#include <ignition/common/Filesystem.hh>
+#include <ignition/common/Event.hh>
+#include <ignition/sensors/Manager.hh>
+#include <ignition/sensors/RgbdCameraSensor.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering is disabling the
 // warnings
@@ -39,11 +39,11 @@
 #pragma warning(push)
 #pragma warning(disable: 4251)
 #endif
-#include <gz/rendering/Material.hh>
-#include <gz/rendering/RenderEngine.hh>
-#include <gz/rendering/RenderingIface.hh>
-#include <gz/rendering/Scene.hh>
-#include <gz/rendering/Visual.hh>
+#include <ignition/rendering/Material.hh>
+#include <ignition/rendering/RenderEngine.hh>
+#include <ignition/rendering/RenderingIface.hh>
+#include <ignition/rendering/Scene.hh>
+#include <ignition/rendering/Visual.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
@@ -56,7 +56,7 @@
 #define DEPTH_TOL 1e-4
 #define DOUBLE_TOL 1e-6
 
-using namespace gz;
+using namespace ignition;
 
 std::mutex g_mutex;
 unsigned int g_depthCounter = 0;
@@ -74,9 +74,9 @@ unsigned char *g_pointsRGBBuffer = nullptr;
 
 std::mutex g_infoMutex;
 unsigned int g_infoCounter = 0;
-msgs::CameraInfo g_infoMsg;
+ignition::msgs::CameraInfo g_infoMsg;
 
-void UnpackPointCloudMsg(const msgs::PointCloudPacked &_msg,
+void UnpackPointCloudMsg(const ignition::msgs::PointCloudPacked &_msg,
   float *_xyzBuffer, unsigned char *_rgbBuffer)
 {
   std::string msgBuffer = _msg.data();
@@ -115,7 +115,7 @@ void UnpackPointCloudMsg(const msgs::PointCloudPacked &_msg,
 }
 
 
-void OnCameraInfo(const msgs::CameraInfo & _msg)
+void OnCameraInfo(const ignition::msgs::CameraInfo & _msg)
 {
   g_infoMutex.lock();
   g_infoCounter++;
@@ -123,7 +123,7 @@ void OnCameraInfo(const msgs::CameraInfo & _msg)
   g_infoMutex.unlock();
 }
 
-void OnDepthImage(const msgs::Image &_msg)
+void OnDepthImage(const ignition::msgs::Image &_msg)
 {
   g_mutex.lock();
   unsigned int depthSamples = _msg.width() * _msg.height();
@@ -135,7 +135,7 @@ void OnDepthImage(const msgs::Image &_msg)
   g_mutex.unlock();
 }
 
-void OnImage(const msgs::Image &_msg)
+void OnImage(const ignition::msgs::Image &_msg)
 {
   g_imgMutex.lock();
   unsigned int imgSize = _msg.width() * _msg.height() * 3;
@@ -146,7 +146,7 @@ void OnImage(const msgs::Image &_msg)
   g_imgMutex.unlock();
 }
 
-void OnPointCloud(const msgs::PointCloudPacked &_msg)
+void OnPointCloud(const ignition::msgs::PointCloudPacked &_msg)
 {
   g_pcMutex.lock();
 
@@ -174,7 +174,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     const std::string &_renderEngine)
 {
   // get the darn test data
-  std::string path = common::joinPaths(PROJECT_SOURCE_PATH, "test",
+  std::string path = ignition::common::joinPaths(PROJECT_SOURCE_PATH, "test",
       "integration", "rgbd_camera_sensor_builtin.sdf");
   sdf::SDFPtr doc(new sdf::SDF());
   sdf::init(doc);
@@ -199,7 +199,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   double near_ = clipPtr->Get<double>("near");
 
   double unitBoxSize = 1.0;
-  math::Vector3d boxPosition(3.0, 0.0, 0.0);
+  ignition::math::Vector3d boxPosition(3.0, 0.0, 0.0);
 
   // If ogre is not the engine, don't run the test
   if ((_renderEngine.compare("ogre") != 0) &&
@@ -211,7 +211,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = rendering::engine(_renderEngine);
+  auto *engine = ignition::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -219,37 +219,36 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     return;
   }
 
-  rendering::ScenePtr scene = engine->CreateScene("scene");
+  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // Create an scene with a box in it
   scene->SetAmbientLight(0.0, 0.0, 1.0);
-  rendering::VisualPtr root = scene->RootVisual();
+  ignition::rendering::VisualPtr root = scene->RootVisual();
 
   // red background
   scene->SetBackgroundColor(1.0, 0.0, 0.0);
 
   // create blue material
-  rendering::MaterialPtr blue = scene->CreateMaterial();
+  ignition::rendering::MaterialPtr blue = scene->CreateMaterial();
   blue->SetAmbient(0.0, 0.0, 1.0);
   blue->SetDiffuse(0.0, 0.0, 1.0);
   blue->SetSpecular(0.0, 0.0, 1.0);
 
   // create box visual
-  rendering::VisualPtr box = scene->CreateVisual();
+  ignition::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
   box->SetLocalRotation(0, 0, 0);
   box->SetLocalScale(unitBoxSize, unitBoxSize, unitBoxSize);
   box->SetMaterial(blue);
-  scene->DestroyMaterial(blue);
   root->AddChild(box);
 
   // do the test
-  sensors::Manager mgr;
+  ignition::sensors::Manager mgr;
 
-  sensors::RgbdCameraSensor *rgbdSensor =
-      mgr.CreateSensor<sensors::RgbdCameraSensor>(sensorPtr);
+  ignition::sensors::RgbdCameraSensor *rgbdSensor =
+      mgr.CreateSensor<ignition::sensors::RgbdCameraSensor>(sensorPtr);
   ASSERT_NE(rgbdSensor, nullptr);
   rgbdSensor->SetScene(scene);
 
@@ -258,30 +257,30 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
 
   std::string depthTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/depth_image";
-  WaitForMessageTestHelper<msgs::Image> depthHelper(depthTopic);
+  WaitForMessageTestHelper<ignition::msgs::Image> depthHelper(depthTopic);
 
   std::string imageTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/image";
-  WaitForMessageTestHelper<msgs::Image> imageHelper(imageTopic);
+  WaitForMessageTestHelper<ignition::msgs::Image> imageHelper(imageTopic);
 
   std::string pointsTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/points";
-  WaitForMessageTestHelper<msgs::PointCloudPacked>
+  WaitForMessageTestHelper<ignition::msgs::PointCloudPacked>
       pointsHelper(pointsTopic);
 
   std::string infoTopic =
     "/test/integration/RgbdCameraPlugin_imagesWithBuiltinSDF/camera_info";
-  WaitForMessageTestHelper<msgs::CameraInfo> infoHelper(infoTopic);
+  WaitForMessageTestHelper<ignition::msgs::CameraInfo> infoHelper(infoTopic);
 
   // Update once to create image
-  mgr.RunOnce(common::Time::Zero);
+  mgr.RunOnce(std::chrono::steady_clock::duration::zero());
 
   EXPECT_TRUE(depthHelper.WaitForMessage()) << depthHelper;
   EXPECT_TRUE(imageHelper.WaitForMessage()) << imageHelper;
   EXPECT_TRUE(pointsHelper.WaitForMessage()) << pointsHelper;
 
   // subscribe to the depth camera topic
-  transport::Node node;
+  ignition::transport::Node node;
   node.Subscribe(depthTopic, &OnDepthImage);
 
   // subscribe to the image topic
@@ -294,15 +293,16 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   node.Subscribe(infoTopic, &OnCameraInfo);
 
   // Update once more
-  mgr.RunOnce(common::Time::Zero, true);
+  mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
 
   // wait for an image
-  common::Time waitTime = common::Time(0.001);
+  auto waitTime = std::chrono::duration_cast< std::chrono::milliseconds >(
+      std::chrono::duration< double >(0.001));
   int counter = 0;
   int infoCounter = 0;
   int imgCounter = 0;
   int pcCounter = 0;
-  msgs::CameraInfo infoMsg;
+  ignition::msgs::CameraInfo infoMsg;
   for (int sleep = 0; sleep < 300 &&
       (counter == 0 || infoCounter == 0 || imgCounter == 0 || pcCounter == 0);
       ++sleep)
@@ -320,7 +320,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     g_infoMutex.unlock();
     g_imgMutex.unlock();
     g_pcMutex.unlock();
-    common::Time::Sleep(waitTime);
+    std::this_thread::sleep_for(waitTime);
   }
 
   g_mutex.lock();
@@ -363,8 +363,8 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_NEAR(g_depthBuffer[mid], expectedRangeAtMidPoint, DEPTH_TOL);
 
     // The left and right side of the depth frame should be inf
-    EXPECT_DOUBLE_EQ(g_depthBuffer[left], math::INF_D);
-    EXPECT_DOUBLE_EQ(g_depthBuffer[right], math::INF_D);
+    EXPECT_DOUBLE_EQ(g_depthBuffer[left], ignition::math::INF_D);
+    EXPECT_DOUBLE_EQ(g_depthBuffer[right], ignition::math::INF_D);
   }
 
   // check color
@@ -375,7 +375,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/gazebosim/gz-sensors/issues/66
+    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -406,16 +406,16 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     float lx = g_pointsXYZBuffer[imgLeft];
     float ly = g_pointsXYZBuffer[imgLeft + 1];
     float lz = g_pointsXYZBuffer[imgLeft + 2];
-    EXPECT_FLOAT_EQ(math::INF_D, lx);
-    EXPECT_FLOAT_EQ(math::INF_D, ly);
-    EXPECT_FLOAT_EQ(math::INF_D, lz);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, lx);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, ly);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, lz);
 
     float rx = g_pointsXYZBuffer[imgRight];
     float ry = g_pointsXYZBuffer[imgRight + 1];
     float rz = g_pointsXYZBuffer[imgRight + 2];
-    EXPECT_FLOAT_EQ(math::INF_D, rx);
-    EXPECT_FLOAT_EQ(math::INF_D, ry);
-    EXPECT_FLOAT_EQ(math::INF_D, rz);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, rx);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, ry);
+    EXPECT_FLOAT_EQ(ignition::math::INF_D, rz);
 
     // point to the left of mid point should have larger y value than mid
     // point, which in turn should have large y value than point to the
@@ -441,7 +441,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     EXPECT_EQ(0u, mr);
     EXPECT_EQ(0u, mg);
 #ifndef __APPLE__
-    // See https://github.com/gazebosim/gz-sensors/issues/66
+    // See https://github.com/ignitionrobotics/ign-sensors/issues/66
     EXPECT_GT(mb, 0u);
 #endif
 
@@ -465,7 +465,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   // result against actual point cloud data
   {
     // init the point cloud msg to be filled
-    msgs::PointCloudPacked pointsMsg;
+    ignition::msgs::PointCloudPacked pointsMsg;
     msgs::InitPointCloudPacked(pointsMsg, "depth2Image", true,
         {{"xyz", msgs::PointCloudPacked::Field::FLOAT32},
          {"rgb", msgs::PointCloudPacked::Field::FLOAT32}});
@@ -474,7 +474,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     pointsMsg.set_row_step(pointsMsg.point_step() * rgbdSensor->ImageWidth());
 
     // fill msg does the conversion from depth to points
-    sensors::PointCloudUtil pointsUtil;
+    ignition::sensors::PointCloudUtil pointsUtil;
     pointsUtil.FillMsg(pointsMsg, 1.05, g_pointsRGBBuffer, g_depthBuffer);
 
     // Unpack the point cloud msg into separate rgb and xyz buffers
@@ -527,11 +527,13 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
 
   // Check that for a box really close it returns -inf
-  math::Vector3d boxPositionNear(
+  root->RemoveChild(box);
+  ignition::math::Vector3d boxPositionNear(
       unitBoxSize * 0.5 + near_ * 0.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionNear);
+  root->AddChild(box);
 
-  mgr.RunOnce(common::Time::Zero, true);
+  mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0; sleep < 300 &&
       (counter == 0 || infoCounter == 0 || imgCounter == 0 || pcCounter == 0);
       ++sleep)
@@ -549,7 +551,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     g_infoMutex.unlock();
     g_imgMutex.unlock();
     g_pcMutex.unlock();
-    common::Time::Sleep(waitTime);
+    std::this_thread::sleep_for(waitTime);
   }
 
   g_mutex.lock();
@@ -577,7 +579,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
       for (unsigned int j = 0; j < rgbdSensor->ImageWidth(); ++j)
       {
         unsigned int index = step + j;
-        EXPECT_FLOAT_EQ(-math::INF_D, g_depthBuffer[index]);
+        EXPECT_FLOAT_EQ(-ignition::math::INF_D, g_depthBuffer[index]);
       }
     }
   }
@@ -611,9 +613,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
         float x = g_pointsXYZBuffer[index];
         float y = g_pointsXYZBuffer[index + 1];
         float z = g_pointsXYZBuffer[index + 2];
-        EXPECT_FLOAT_EQ(-math::INF_D, x);
-        EXPECT_FLOAT_EQ(-math::INF_D, y);
-        EXPECT_FLOAT_EQ(-math::INF_D, z);
+        EXPECT_FLOAT_EQ(-ignition::math::INF_D, x);
+        EXPECT_FLOAT_EQ(-ignition::math::INF_D, y);
+        EXPECT_FLOAT_EQ(-ignition::math::INF_D, z);
 
         unsigned int r = g_pointsRGBBuffer[index];
         unsigned int g = g_pointsRGBBuffer[index + 1];
@@ -631,11 +633,13 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_pcMutex.unlock();
 
   // Check that for a box really far it returns inf
-  math::Vector3d boxPositionFar(
+  root->RemoveChild(box);
+  ignition::math::Vector3d boxPositionFar(
       unitBoxSize * 0.5 + far_ * 1.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionFar);
+  root->AddChild(box);
 
-  mgr.RunOnce(common::Time::Zero, true);
+  mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0; sleep < 300 &&
       (counter == 0 || infoCounter == 0 || imgCounter == 0 || pcCounter == 0);
       ++sleep)
@@ -653,7 +657,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
     g_infoMutex.unlock();
     g_imgMutex.unlock();
     g_pcMutex.unlock();
-    common::Time::Sleep(waitTime);
+    std::this_thread::sleep_for(waitTime);
   }
 
   g_mutex.lock();
@@ -681,7 +685,7 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
       for (unsigned int j = 0; j < rgbdSensor->ImageWidth(); ++j)
       {
         unsigned int index = step + j;
-        EXPECT_FLOAT_EQ(math::INF_D, g_depthBuffer[index]);
+        EXPECT_FLOAT_EQ(ignition::math::INF_D, g_depthBuffer[index]);
       }
     }
   }
@@ -715,9 +719,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
         float x = g_pointsXYZBuffer[index];
         float y = g_pointsXYZBuffer[index + 1];
         float z = g_pointsXYZBuffer[index + 2];
-        EXPECT_FLOAT_EQ(math::INF_D, x);
-        EXPECT_FLOAT_EQ(math::INF_D, y);
-        EXPECT_FLOAT_EQ(math::INF_D, z);
+        EXPECT_FLOAT_EQ(ignition::math::INF_D, x);
+        EXPECT_FLOAT_EQ(ignition::math::INF_D, y);
+        EXPECT_FLOAT_EQ(ignition::math::INF_D, z);
 
         unsigned int r = g_pointsRGBBuffer[index];
         unsigned int g = g_pointsRGBBuffer[index + 1];
@@ -734,14 +738,9 @@ void RgbdCameraSensorTest::ImagesWithBuiltinSDF(
   g_imgMutex.unlock();
   g_pcMutex.unlock();
 
-  // Clean up rendering ptrs
-  box.reset();
-  blue.reset();
-
   // Clean up
-  mgr.Remove(rgbdSensor->Id());
   engine->DestroyScene(scene);
-  rendering::unloadEngine(engine->Name());
+  ignition::rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
@@ -751,12 +750,12 @@ TEST_P(RgbdCameraSensorTest, ImagesWithBuiltinSDF)
 }
 
 INSTANTIATE_TEST_CASE_P(RgbdCameraSensor, RgbdCameraSensorTest,
-    RENDER_ENGINE_VALUES, rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
-  common::Console::SetVerbosity(4);
+  ignition::common::Console::SetVerbosity(4);
   ::testing::InitGoogleTest(&argc, argv);
   return RUN_ALL_TESTS();
 }
